@@ -64,7 +64,7 @@ def apply_credentials_from_cfg(hostname, http_path, access_token, auth_type, cfg
     """
 
     if not cfg.get("credentials"):
-        return hostname, http_path, access_token
+        return hostname, http_path, access_token, auth_type
 
     hostname = hostname or cfg.get("credentials", {}).get("host_name")
     http_path = http_path or cfg.get("credentials", {}).get("http_path")
